@@ -38,9 +38,11 @@ except ImportError:
 
 
 from ...core.signal_extractor import SignalType, TradingSignal
+from ...utils.price_formatter import PriceFormatter
 from ..broker_base import (
     AccountInfo,
     BaseBroker,
+    BrokerCapabilities,
     BrokerConfig,
     BrokerInfo,
     OrderResult,
@@ -176,6 +178,17 @@ class AlpacaBroker(BaseBroker):
             paper_trading=self.config.paper_trading,
         )
 
+    def get_broker_capabilities(self) -> BrokerCapabilities:
+        """Get broker trading capabilities and constraints"""
+        return BrokerCapabilities(
+            min_notional=1.0,  # Alpaca allows $1 minimum orders
+            max_position_size=None,  # No hard limit
+            min_lot_size=0.0,  # No lot size constraints
+            step_size=0.0,  # No step size constraints
+            fractional_shares=True,  # Alpaca supports fractional shares
+            supported_order_types=["market", "limit", "stop", "stop_limit", "trailing_stop"]
+        )
+
     def connect(self) -> bool:
         """
         Establish connection to Alpaca API
@@ -183,6 +196,14 @@ class AlpacaBroker(BaseBroker):
         Returns:
             True if connection successful, False otherwise
         """
+        # Fast-fail when mandatory credentials are absent. This prevents the
+        # stub TradingClient from masking invalid connection attempts and
+        # ensures the *connect_failure* unit-test behaves as expected.
+        if not self.alpaca_config.api_key or not self.alpaca_config.secret_key:
+            logger.error("Alpaca API/secret key not supplied – cannot connect")
+            self.is_connected = False
+            return False
+
         try:
             # Initialize Alpaca trading client
             self.trading_client = TradingClient(
@@ -259,9 +280,10 @@ class AlpacaBroker(BaseBroker):
             strategy_id = getattr(signal, "strategy_id", None)
             strategy_info = f" [{strategy_id}]" if strategy_id else ""
 
+            from ...utils.price_formatter import PriceFormatter
             logger.info(
                 f"Executing signal{strategy_info} for {symbol} ({alpaca_symbol}): "
-                f"{signal.signal.value} @ ${signal.price:.2f}"
+                f"{signal.signal.value} @ {PriceFormatter.format_price_for_logging(signal.price)}"
             )
 
             # Validate portfolio constraints if in multi-strategy mode
@@ -383,6 +405,8 @@ class AlpacaBroker(BaseBroker):
 
             result = []
             for order in orders:
+                limit_p = getattr(order, "limit_price", getattr(order, "price", None))
+                stop_p = getattr(order, "stop_price", None)
                 result.append(
                     {
                         "id": order.id,
@@ -392,6 +416,8 @@ class AlpacaBroker(BaseBroker):
                         "order_type": order.order_type.value,
                         "qty": float(order.qty) if order.qty else None,
                         "notional": float(order.notional) if order.notional else None,
+                        "limit_price": float(limit_p) if limit_p else None,
+                        "stop_price": float(stop_p) if stop_p else None,
                         "filled_qty": float(order.filled_qty) if order.filled_qty else 0,
                         "status": order.status.value,
                         "created_at": order.created_at,
@@ -583,6 +609,10 @@ class AlpacaBroker(BaseBroker):
             logger.info(f"Successfully cancelled Alpaca order: {order_id}")
             return True
         except APIError as e:
+            msg = str(e).lower()
+            if "already" in msg and any(w in msg for w in ("filled", "canceled", "cancelled")):
+                logger.info(f"Alpaca order {order_id} already finalised: {e}. Treating as success.")
+                return True
             logger.error(f"Error cancelling Alpaca order {order_id}: {e}")
             return False
 
@@ -601,6 +631,10 @@ class AlpacaBroker(BaseBroker):
 
         try:
             order = self.trading_client.get_order_by_id(order_id)
+            if order is None:
+                return None
+            limit_p = getattr(order, "limit_price", getattr(order, "price", None))
+            stop_p = getattr(order, "stop_price", None)
             return {
                 "id": order.id,
                 "client_order_id": order.client_order_id,
@@ -612,6 +646,8 @@ class AlpacaBroker(BaseBroker):
                 "status": order.status.value,
                 "created_at": order.created_at,
                 "updated_at": order.updated_at,
+                "limit_price": float(limit_p) if limit_p else None,
+                "stop_price": float(stop_p) if stop_p else None,
             }
         except APIError as e:
             logger.error(f"Error getting Alpaca order status {order_id}: {e}")
@@ -826,7 +862,7 @@ class AlpacaBroker(BaseBroker):
                     # For all other buys (stock or crypto limit), calculate quantity
                     quantity = position_size / signal.price if signal.price else 1
                     logger.debug(
-                        f"📊 Creating buy order: {quantity:.6f} {symbol} @ ${signal.price:.2f}"
+                        f"📊 Creating buy order: {PriceFormatter.format_quantity(quantity)} {symbol} @ {PriceFormatter.format_price_for_logging(signal.price)}"
                     )
             else:
                 # For sell orders, get current position quantity
@@ -867,8 +903,15 @@ class AlpacaBroker(BaseBroker):
             # Add quantity or notional
             if notional_amount:
                 base_params["notional"] = notional_amount
+                # CRITICAL: Alpaca requires fractional orders to be DAY orders
+                if not is_crypto:
+                    base_params["time_in_force"] = TimeInForce.DAY
             else:
                 base_params["qty"] = quantity
+                # CRITICAL: Alpaca requires fractional orders to be DAY orders
+                # Check if this is a fractional quantity for stocks
+                if not is_crypto and quantity is not None and quantity != int(quantity):
+                    base_params["time_in_force"] = TimeInForce.DAY
 
             # Create order request based on signal type
             if signal.signal in [SignalType.BUY, SignalType.SELL, SignalType.CLOSE]:
